@@ -14,21 +14,28 @@ Usage::
 from typing import Any, Dict, Type
 
 from botocore.client import ClientMeta
-from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_workmailmessageflow.type_defs import GetRawMessageContentResponseTypeDef
 
 __all__ = ("WorkMailMessageFlowClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
-    ClientError: Type[Boto3ClientError]
-    ResourceNotFoundException: Type[Boto3ClientError]
+    ClientError: Type[BotocoreClientError]
+    ResourceNotFoundException: Type[BotocoreClientError]
 
 
 class WorkMailMessageFlowClient:
     """
-    [WorkMailMessageFlow.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client)
+    [WorkMailMessageFlow.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client)
     """
 
     meta: ClientMeta
@@ -36,7 +43,7 @@ class WorkMailMessageFlowClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -47,10 +54,10 @@ class WorkMailMessageFlowClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.generate_presigned_url)
         """
 
     def get_raw_message_content(self, messageId: str) -> GetRawMessageContentResponseTypeDef:
         """
-        [Client.get_raw_message_content documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.get_raw_message_content)
+        [Client.get_raw_message_content documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.get_raw_message_content)
         """
